quanta.bybit.blotter.query


derivative-position->positionclj

(derivative-position->position account-id _req-id category row)
(derivative-position->position account-id
                               _req-id
                               category
                               mode
                               {:keys [symbol side size avgPrice markPrice
                                       positionIdx]})

Bybit position list row -> an OMS :position/* map. mode is :main or :test (from account connection settings).

Bybit position list row -> an OMS `:position/*` map.
`mode` is `:main` or `:test` (from account connection settings).
raw docstring

open-order->orderclj

(open-order->order account-id category row)
(open-order->order account-id
                   category
                   mode
                   {:keys [orderLinkId symbol side qty price triggerPrice
                           orderType leavesQty cumExecQty avgPrice updatedTime
                           createdTime orderStatus]})

Bybit open order row -> an OMS :order/* map.

Bybit open order row -> an OMS `:order/*` map.
raw docstring

open-positions-reportclj

(open-positions-report account req-id log)

Missionary task producing a vector of OMS :position/* maps.

Missionary task producing a vector of OMS `:position/*` maps.
raw docstring

run-queryclj

(run-query account req log)

Execute a trader snapshot request and return a task of OMS-shaped records.

Execute a trader snapshot request and return a task of OMS-shaped records.
raw docstring

wallet-coin->positionclj

(wallet-coin->position account-id _req-id coin-row)
(wallet-coin->position account-id _req-id mode {:keys [coin walletBalance]})

Wallet coin row -> an OMS :position/* map.

Wallet coin row -> an OMS `:position/*` map.
raw docstring

working-orders-reportclj

(working-orders-report account _req-id log)

Missionary task producing a vector of OMS :order/* maps.

Missionary task producing a vector of OMS `:order/*` maps.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries