quanta.bybit.impl.asset-converter


->bybit-asset-mapperclj

(->bybit-asset-mapper account log)

Positional factory function for class quanta.bybit.impl.asset_converter.bybit-asset-mapper.

Positional factory function for class quanta.bybit.impl.asset_converter.bybit-asset-mapper.
raw docstring

category-matches-asset?clj

(category-matches-asset? account-category asset-id)

connection-modeclj

(connection-mode account)

Account :account/settings :connection :mode:main or :test (default :main).

Account `:account/settings :connection :mode` — `:main` or `:test` (default `:main`).
raw docstring

from-api-with-categoryclj

(from-api-with-category account symbol category)

Map Bybit API symbol + market category to blotter asset using account connection :mode. Use this on trade/private/query paths where category comes from the Bybit payload (not from quote-account :connection :category).

Map Bybit API symbol + market category to blotter asset using account connection `:mode`.
Use this on trade/private/query paths where category comes from the Bybit payload
(not from quote-account `:connection :category`).
raw docstring

map->bybit-asset-mapperclj

(map->bybit-asset-mapper m__7972__auto__)

Factory function for class quanta.bybit.impl.asset_converter.bybit-asset-mapper, taking a map of keywords to field values.

Factory function for class quanta.bybit.impl.asset_converter.bybit-asset-mapper, taking a map of keywords to field values.
raw docstring

parse-asset-idclj

(parse-asset-id asset-id)

Parse BTCUSDT.LF.BB / BTCUSDT.LF.BBT -> {:symbol ... :category ... :endpoint ...} or nil.

Parse `BTCUSDT.LF.BB` / `BTCUSDT.LF.BBT` -> `{:symbol ... :category ... :endpoint ...}` or nil.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries