quanta.bybit.blotter.query


derivative-position->itemclj

(derivative-position->item account-id
                           req-id
                           category
                           {:keys [symbol side size avgPrice markPrice
                                   positionIdx]})

Bybit position list row -> :broker/positions-item (without :total).

Bybit position list row -> `:broker/positions-item` (without :total).
raw docstring

open-order->statusclj

(open-order->status account-id
                    category
                    {:keys [orderLinkId orderId symbol side qty price orderType
                            timeInForce leavesQty cumExecQty updatedTime
                            createdTime orderStatus]})

Bybit open order row -> :broker/order-status.

Bybit open order row -> `:broker/order-status`.
raw docstring

open-positions-reportclj

(open-positions-report account req-id log)

Missionary task producing a vector of :broker/positions-item messages.

Missionary task producing a vector of `:broker/positions-item` messages.
raw docstring

run-queryclj

(run-query account req log)

Execute a trader snapshot request and return a missionary task of blotter updates.

Execute a trader snapshot request and return a missionary task of blotter updates.
raw docstring

wallet-coin->itemclj

(wallet-coin->item account-id req-id {:keys [coin walletBalance]})

Wallet coin row -> :broker/positions-item (without :total).

Wallet coin row -> `:broker/positions-item` (without :total).
raw docstring

working-orders-reportclj

(working-orders-report account _req-id log)

Missionary task producing a vector of :broker/order-status messages.

Missionary task producing a vector of `:broker/order-status` messages.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries