(->bybit-asset-mapper account log)Positional factory function for class quanta.bybit.impl.asset_converter.bybit-asset-mapper.
Positional factory function for class quanta.bybit.impl.asset_converter.bybit-asset-mapper.
(category-matches-asset? account-category asset-id)(map->bybit-asset-mapper m__7972__auto__)Factory function for class quanta.bybit.impl.asset_converter.bybit-asset-mapper, taking a map of keywords to field values.
Factory function for class quanta.bybit.impl.asset_converter.bybit-asset-mapper, taking a map of keywords to field values.
(parse-asset-id asset-id)Parse BTCUSDT.LF.BB / BTCUSDT.LF.BBT -> {:symbol ... :category ... :endpoint ...} or nil.
Parse `BTCUSDT.LF.BB` / `BTCUSDT.LF.BBT` -> `{:symbol ... :category ... :endpoint ...}` or nil.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |