quanta.bybit.impl.asset-converter


->bybit-asset-mapperclj

(->bybit-asset-mapper account log)

Positional factory function for class quanta.bybit.impl.asset_converter.bybit-asset-mapper.

Positional factory function for class quanta.bybit.impl.asset_converter.bybit-asset-mapper.
raw docstring

category-matches-asset?clj

(category-matches-asset? account-category asset-id)

map->bybit-asset-mapperclj

(map->bybit-asset-mapper m__7972__auto__)

Factory function for class quanta.bybit.impl.asset_converter.bybit-asset-mapper, taking a map of keywords to field values.

Factory function for class quanta.bybit.impl.asset_converter.bybit-asset-mapper, taking a map of keywords to field values.
raw docstring

parse-asset-idclj

(parse-asset-id asset-id)

Parse BTCUSDT.LF.BB -> {:symbol ... :category ...} or nil.

Parse `BTCUSDT.LF.BB` -> `{:symbol ... :category ...}` or nil.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries